@@ -60,7 +60,7 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
                 "Choose your Position Size for {} per trade in %: ".format(symbol))
             pos_size = check_pos_size(pos_size)
             symbol_settings.append(Symbol(name=symbol, position_size=pos_size))
-        return make_pickle_file(settings_path, settings_name, token, api_key, api_secret, symbol_settings)
+        return make_pickle_file(settings_path, setting_name, token, api_key, api_secret, symbol_settings)
 
 
 def position_symbol_sizes(symbols):
